import { ArrowDown } from "lucide-react";
import { useSmoothScroll } from "../../hooks/use-smooth-scroll";

// Import custom HD PNG icons
import runwayDrainIcon from "@assets/Runway Drain.png";
import opportunityLostIcon from "@assets/Opportunity Lost.png";
import founderGridlockIcon from "@assets/Founder Gridlock.png";
import momentumCrushedIcon from "@assets/Momentum Crushed.png";

const Problem = () => {
  const { scrollToSection } = useSmoothScroll();

  return (
    <section id="problem" className="pt-16 pb-8 md:pt-24 md:pb-12 bg-[#F4F1E1]">
      <div className="container mx-auto px-4">
        <h2 className="text-3xl md:text-4xl font-bold font-poppins text-[#2B144D] text-center mb-12">
          THE SLOW, EXPENSIVE HIRES CRIPPLING INDIAN STARTUPS
        </h2>
        <p className="text-xl text-center max-w-4xl mx-auto mb-12">
          You know the drill. Building fast in India is war. But hiring feels like fighting with one hand tied:
        </p>
        
        <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8 max-w-6xl mx-auto">
          {/* Problem Card 1 - Leaking Money Bag */}
          <div className="bg-white p-8 rounded-lg shadow-md hover:shadow-xl transform transition-all duration-300 hover:-translate-y-1 group">
            <div className="mb-4 flex justify-center">
              <img 
                src={runwayDrainIcon} 
                alt="Runway Drain Icon" 
                className="h-20 w-20 group-hover:scale-110 transition-transform duration-300 object-contain" 
              />
            </div>
            <h3 className="text-xl font-bold text-[#2B144D] mb-3 text-center">Runway Drain</h3>
            <p className="text-gray-700 text-center">
              Every % fee paid to traditional recruiters (8%-20%) is <strong>cash squandered</strong> – money stolen from product, growth, survival.
            </p>
          </div>
          
          {/* Problem Card 2 - Empty Office Chair */}
          <div className="bg-white p-8 rounded-lg shadow-md hover:shadow-xl transform transition-all duration-300 hover:-translate-y-1 group">
            <div className="mb-4 flex justify-center">
              <img 
                src={opportunityLostIcon} 
                alt="Opportunity Lost Icon" 
                className="h-20 w-20 group-hover:scale-110 transition-transform duration-300 object-contain" 
              />
            </div>
            <h3 className="text-xl font-bold text-[#2B144D] mb-3 text-center">Opportunity Lost</h3>
            <p className="text-gray-700 text-center">
              Critical roles vacant = <strong>market share GONE.</strong> Competitors are hiring <em>right now</em>. Your delay is their advantage. Can you afford it?
            </p>
          </div>
          
          {/* Problem Card 3 - Person Juggling Multiple Balls */}
          <div className="bg-white p-8 rounded-lg shadow-md hover:shadow-xl transform transition-all duration-300 hover:-translate-y-1 group">
            <div className="mb-4 flex justify-center">
              <img 
                src={founderGridlockIcon} 
                alt="Founder Gridlock Icon" 
                className="h-20 w-20 group-hover:scale-110 transition-transform duration-300 object-contain" 
              />
            </div>
            <h3 className="text-xl font-bold text-[#2B144D] mb-3 text-center">Founder Gridlock</h3>
            <p className="text-gray-700 text-center">
              Are you the CEO or the Chief CV Screener? Your time is worth lakhs per hour. Stop wasting it on low-value tasks that <strong>we master.</strong>
            </p>
          </div>
          
          {/* Problem Card 4 - Fractured Upward Arrow */}
          <div className="bg-white p-8 rounded-lg shadow-md hover:shadow-xl transform transition-all duration-300 hover:-translate-y-1 group">
            <div className="mb-4 flex justify-center">
              <img 
                src={momentumCrushedIcon} 
                alt="Momentum Crushed Icon" 
                className="h-20 w-20 group-hover:scale-110 transition-transform duration-300 object-contain" 
              />
            </div>
            <h3 className="text-xl font-bold text-[#2B144D] mb-3 text-center">Momentum Crushed</h3>
            <p className="text-gray-700 text-center">
              Stop-start hiring demoralizes your team, creates chaos, and makes scaling a painful lurch instead of a smooth ascent.
            </p>
          </div>
        </div>
        
        <div className="text-center mt-12">
          <p className="text-xl font-bold text-[#2B144D] mb-4">Stop the Bleeding. There IS a better way.</p>
          <div className="h-1 w-32 bg-[#D1BEEE] mx-auto mb-8"></div>
          <a 
            href="#contact"
            onClick={(e) => {
              e.preventDefault();
              scrollToSection('#contact');
            }}
            className="inline-block bg-[#CF2C2C] hover:bg-[#CF2C2C]/90 text-white font-bold py-3 px-8 rounded-lg shadow-lg transform transition-all duration-300 ease-in-out hover:-translate-y-1 hover:shadow-xl text-lg relative group"
          >
            <span className="relative flex items-center">
              LET'S TALK
              <ArrowDown className="ml-2 h-5 w-5 opacity-0 group-hover:opacity-100 transition-all duration-300 ease-in-out group-hover:translate-y-1" />
            </span>
            <span className="absolute inset-0 border-2 border-white/0 group-hover:border-white/40 rounded-lg scale-105 transition-all duration-300 ease-in-out"></span>
          </a>
        </div>
      </div>
    </section>
  );
};

export default Problem;
